@@ -8,6 +8,11 @@
 #include <QtDebug>
 #include <QGLContext>
 
+#ifndef Q_WS_MAC
+#include <QDBusConnection>
+#include <QDBusMessage>
+#endif
+
 QmlLoader::QmlLoader():
         QDeclarativeView()       
 {
@@ -29,7 +34,7 @@ QmlLoader::QmlLoader():
     
     // Expose the C++ interface to QML
     engine()->rootContext()->setContextProperty("flickrManager", m_flickrManager );
-    
+    engine()->rootContext()->setContextProperty("mainWindow", this );
     
     // Load the main QML component which constructs the whole UI from other
     // QML components    
@@ -38,6 +43,18 @@ QmlLoader::QmlLoader():
 }
 
 
+void QmlLoader::minimize()
+{
+#ifndef Q_WS_MAC
+     QDBusConnection c = QDBusConnection::sessionBus();
+     QDBusMessage m = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");
+     c.send(m);
+#else
+     showMinimized();
+#endif
+}
+
+
 
 
 
